<?php
	
use Elementor\Plugin;
if (!defined('ABSPATH')) {
    exit;
}

class Theplus_Elementor_Plugin_Options
{
    
    /**
     * Option key, and option page slug
     * @var string
     */
    private $key = 'theplus_options';
    
    /**
     * Array of metaboxes/fields
     * @var array
     */
    protected $option_metabox = array();
    
    /**
     * Options Page title
     * @var string
     */
    protected $title = '';
    
    /**
     * Options Page hook
     * @var string
     */
    protected $options_page = '';
    protected $options_pages = array();
    /**
     * Constructor
     * @since 0.1.0
     */
    public function __construct()
    {
        // Set our title
		add_action( 'admin_enqueue_scripts', array( $this,'theplus_options_scripts') );
        $this->title = __('ThePlus Settings', 'theplus');
        require_once THEPLUS_INCLUDES_URL.'plus-options/cmb2-conditionals.php';
        // Set our CMB fields
        $this->fields = array(
        );
    }
    
    /**
     * Initiate our hooks
     * @since 1.0.0
     */
	public function theplus_options_scripts() {   
		wp_enqueue_script( 'cmb2-conditionals', THEPLUS_URL .'includes/plus-options/cmb2-conditionals.js', array() );
		wp_enqueue_script('thickbox', null, array('jquery'));
		wp_enqueue_style('thickbox.css', '/'.WPINC.'/js/thickbox/thickbox.css', null, '1.0');
	}

    public function hooks()
    {
        add_action('admin_init', array(
            $this,
            'init'
        ));
        add_action('admin_menu', array(
            $this,
            'add_options_page'
        ));
    }
    
    /**
     * Register our setting to WP
     * @since  1.0.0
     */
    public function init()
    {
        //register_setting( $this->key, $this->key );
        $option_tabs = self::option_fields();
        foreach ($option_tabs as $index => $option_tab) {
            register_setting($option_tab['id'], $option_tab['id']);
        }
    }
    
    /**
     * Add menu options page
     * @since 1.0.0
     */
    public function add_options_page()
    {
       
        $option_tabs = self::option_fields();
        foreach ($option_tabs as $index => $option_tab) {
            if ($index == 0) {
                $this->options_pages[] = add_menu_page($this->title, $this->title, 'manage_options', $option_tab['id'], array(
                    $this,
                    'admin_page_display'
                )); //Link admin menu to first tab
                add_submenu_page($option_tabs[0]['id'], $this->title, $option_tab['title'], 'manage_options', $option_tab['id'], array(
                    $this,
                    'admin_page_display'
                )); //Duplicate menu link for first submenu page
            } else {
                $this->options_pages[] = add_submenu_page($option_tabs[0]['id'], $this->title, $option_tab['title'], 'manage_options', $option_tab['id'], array(
                    $this,
                    'admin_page_display'
                ));
            }
        }
    }
    
    /**
     * 
     * @since  1.0.0
     */
    public function admin_page_display()
    {
        $option_tabs = self::option_fields(); //get all option tabs
		$json="json";
        $tab_forms   = array();
		$file_url="http://elementor.theplusaddons.com";
?>

		<div class="<?php  echo $this->key; ?>">
		<div id="ptplus-banner-wrap">
			<div id="ptplus-banner" class="ptplus-banner-sticky">
				<h2><?php echo esc_html__('ThePlus Settings','theplus'); ?><!--<span><img src="<?php echo THEPLUS_URL .'vc_elements/images/thepluslogo.png'; ?>"></span>--></h2>
				<div class="theplus-current-version wp-badge"> <?php echo esc_html__('Version','theplus'); ?> <?php echo THEPLUS_VERSION; ?></div>
			</div>
		</div>
		<h2 class="nav-tab-wrapper">
            	<?php
	        foreach ($option_tabs as $option_tab):
	            $tab_slug  = $option_tab['id'];
	            $nav_class = 'nav-tab';
	            if ($tab_slug == $_GET['page']) {
	                $nav_class .= ' nav-tab-active'; //add active class to current tab
	                $tab_forms[] = $option_tab; //add current tab to forms to be rendered
	            } ?>            	
            	<a class="<?php echo $nav_class; ?>" href="<?php  menu_page_url($tab_slug); ?>"><?php echo esc_html__($option_tab['title']); ?></a>
           	<?php endforeach; ?>
        </h2>
		<?php foreach ($tab_forms as $tab_form): ?>
				
				<?php if($tab_form['id']!='theplus_about_us' && $tab_form['id']!='theplus_import_data'){ ?>
					<div id="<?php echo esc_attr__($tab_form['id']); ?>" class="group theplus_form_content">
						<?php cmb_metabox_form($tab_form, $tab_form['id']); ?>
					</div>
				<?php } ?>
				<?php if($tab_form['id']=='theplus_about_us'){ ?>
				<div class="theplus_about-tab changelog">
					<div class="feature-section">
						<h4 style="padding-left:15px;"><?php echo esc_html__('Welcome to The Plus addons for Elementor. We have tried to get up as much as options possible with great customisation options for you. From this section, We have attached some links which will helpful to you.','theplus'); ?></h4>
						<div class="col-xs-6">
							<h3><?php echo esc_html__('Resources :','theplus'); ?></h3>
							<ul>
								<li>
									<a href="http://elementor.theplusaddons.com/documentation/" target="_blank"><?php echo esc_html__('Visit Our Main Page : Live Demo','theplus'); ?></a></li>
								<li><a href="http://elementor.theplusaddons.com/widgets/" target="_blank"><?php echo esc_html__('Check our 50+ Widgets : Plus Widgets','theplus'); ?></a></li>
								<li><a href="#" target="_blank"><?php echo esc_html__('Our 500+ UI Blocks : Plus Blocks','theplus'); ?></a></li>
								<li><a href="#" target="_blank"><?php echo esc_html__('Visit Grid Builder Options : Plus Listings','theplus'); ?></a></li>
								<li><a href="#"><?php echo esc_html__('Check premade pages : Plus Pages','theplus'); ?></a></li>
							</ul>
						</div>
						
						<div class="col-xs-6">
							<ul style="padding-top: 40px;">
								<li><a href="http://elementor.theplusaddons.com/documentation/" target="_blank"><?php echo esc_html__('Checkout our detailed documentation : Online Documentation','theplus'); ?></a></li>
								<li><a href="https://www.youtube.com/playlist?list=PLFRO-irWzXaLK9H5opSt88xueTnRhqvO5" target="_blank"><?php echo esc_html__('Watch Our Video Tutorials : Video Library','theplus'); ?></a></li>
								<li><a href="https://posimyththemes.ticksy.com/" target="_blank"><?php echo esc_html__('Contact us for any queries : Support Forum','theplus'); ?></a></li>
								<li><a href="https://codecanyon.net/item/the-plus-addon-for-elementor-page-builder-wordpress-plugin/22831875" target="_blank"><?php echo esc_html__('Purchase Another Licence : Buy Now','theplus'); ?></a></li>								
							</ul>
						</div>
					</div>
				</div>
				<?php } ?>
				<?php if($tab_form['id']=='theplus_import_data'){
					$ajax = Plugin::$instance->common->get_component( 'ajax' );
					$templates="templates";
				?>
				<div class="theplus_about-tab changelog">
					<div class="feature-section">
						<div id="pt-plus-import-form">
							<div class="pt_plus_row table_row">
								<div class="pt_col-md-6">
									<div class="pt-plus-section-content plus-widgets" style="width:88%;">
											<div class="pt_plus_row">
													<h3><?php echo esc_html__("Plus Widget (.Json)","theplus"); ?></h3>
													<select name="plus-widget-templates" id="plus-widget-templates" class="form-control pt-plus-form-element">
														<option value=""><?php echo esc_html__("Select Plus Widget Page","theplus"); ?></option>
														<option value="accordion" data-url="accordion"><?php echo esc_html__("Accordion","theplus"); ?></option>
														<option value="advance-text-block" data-url="advance-text-block"><?php echo esc_html__("Advance Text Block","theplus"); ?></option>
														<option value="animated-text" data-url="heading-animation"><?php echo esc_html__("Animated Text","theplus"); ?></option>
														<option value="before-after" data-url="before-after-2"><?php echo esc_html__("Before After","theplus"); ?></option>
														<option value="button" data-url="buttons"><?php echo esc_html__("Button","theplus"); ?></option>
														<option value="canvas-background" data-url="row-background/canvas-background"><?php echo esc_html__("Canvas Background","theplus"); ?></option>
														<option value="contact-form-7" data-url="contact-form-7"><?php echo esc_html__("Contact Form 7","theplus"); ?></option>
														<option value="countdown" data-url="countdown"><?php echo esc_html__("Countdown","theplus"); ?></option>
														<option value="creative-images" data-url="creative-images"><?php echo esc_html__("Creative Images","theplus"); ?></option>
														<option value="device-dynamic" data-url="device-dynamic"><?php echo esc_html__("Dynamic Devices","theplus"); ?></option>
														<option value="filpbox" data-url="flipbox"><?php echo esc_html__("Filpbox","theplus"); ?></option>
														<option value="gallery-background" data-url="row-background/gallery-background"><?php echo esc_html__("Gallery Background","theplus"); ?></option>
														<option value="heading-title" data-url="heading-titles"><?php echo esc_html__("Heading Title","theplus"); ?></option>
														<option value="image-cascading" data-url="image-cascading"><?php echo esc_html__("Image Cascading","theplus"); ?></option>
														<option value="infobox" data-url="infobox"><?php echo esc_html__("Infobox","theplus"); ?></option>
														<option value="mailchimp" data-url="mailchimp"><?php echo esc_html__("MailChimp","theplus"); ?></option>
														<option value="parallax-background" data-url="row-background/parallax-background"><?php echo esc_html__("Parallax Background","theplus"); ?></option>
														<option value="pricing-table" data-url="pricing-table"><?php echo esc_html__("Pricing Table","theplus"); ?></option>
														<option value="row-background" data-url="row-background"><?php echo esc_html__("Row Background","theplus"); ?></option>
														<option value="segment-background" data-url="row-background/segmentation-background"><?php echo esc_html__("Segmentation Background","theplus"); ?></option>
														<option value="smooth-scroll" data-url="smooth-scroll"><?php echo esc_html__("Smooth Scroll","theplus"); ?></option>
														<option value="social-icon" data-url="social-icon"><?php echo esc_html__("Social Icon","theplus"); ?></option>
														<option value="stylish-list" data-url="stylish-list"><?php echo esc_html__("Stylish List","theplus"); ?></option>
														<option value="switcher" data-url="switcher"><?php echo esc_html__("Switcher","theplus"); ?></option>
														<option value="tabs-tours" data-url="tabs-tours"><?php echo esc_html__("Tabs Tours","theplus"); ?></option>
														<option value="video" data-url="videos"><?php echo esc_html__("Video Player","theplus"); ?></option>
													</select>
													<input type="hidden" id="file-get-url" value=<?php echo $file_url; ?>>													
													<a class="widgets-get-template-file" id="widgets-download-template-file" /><?php echo esc_html__("Download File","theplus"); ?></a>
													<a href="#" class="plus-widget-demo-link" target="_blank"><?php echo esc_html__("Demo Link","theplus"); ?></a>
													<div class="loading-bar-plus"><i class="fa fa-spinner" aria-hidden="true"></i></div>
											</div>
									</div>
									<div class="pt-plus-section-content plus-listing" style="width:88%;">
											<div class="pt_plus_row">
													<h3><?php echo esc_html__("Plus Listing (.Json)","theplus"); ?></h3>
													<select name="plus-listing-templates" id="plus-listing-templates" class="form-control pt-plus-form-element">
														<option value=""><?php echo esc_html__("Select Plus Listing Page","theplus"); ?></option>
														<optgroup label="<?php echo esc_html__("Blog Posts","theplus"); ?>">
															<option value="blog-desgin-style" data-url="plus-blogs/blog-styles"><?php echo esc_html__("Design Styles","theplus"); ?></option>
															<option value="blog-grid" data-url="plus-blogs/grid-blogs"><?php echo esc_html__("Grid","theplus"); ?></option>
															<option value="blog-masonry" data-url="plus-blogs/masonry-blogs"><?php echo esc_html__("Masonry","theplus"); ?></option>
															<option value="blog-metro" data-url="plus-blogs/metro-blogs/"><?php echo esc_html__("Metro","theplus"); ?></option>
															<option value="blog-carousel" data-url="plus-blogs/carousel-blogs/"><?php echo esc_html__("Carousel","theplus"); ?></option>
															<option value="blog-filter" data-url="plus-blogs/blog-filter/"><?php echo esc_html__("Filter","theplus"); ?></option>
															<option value="blog-messy-columns" data-url="plus-blogs/messy-columns-blogs/"><?php echo esc_html__("Messy Columns","theplus"); ?></option>
															<option value="blog-stagger-load" data-url="plus-blogs/blog-stagger-load/"><?php echo esc_html__("Stagger Load","theplus"); ?></option>
															<option value="blog-lazy-load" data-url="plus-blogs/lazy-load-blogs/"><?php echo esc_html__("Lazy Load","theplus"); ?></option>
															<option value="blog-pagination" data-url="plus-blogs/pagination-blogs/"><?php echo esc_html__("Pagination","theplus"); ?></option>
															<option value="blog-load-more" data-url="plus-blogs/load-more-blogs/"><?php echo esc_html__("Load More","theplus"); ?></option>
															
														</optgroup>
														<optgroup label="<?php echo esc_html__("Testimonials","theplus"); ?>">
															<option value="testimonial" data-url="testimonial/#section-style-one"><?php echo esc_html__("Design Styles","theplus"); ?></option>
														</optgroup>
														<optgroup label="<?php echo esc_html__("Client Logos","theplus"); ?>">
															<option value="clients-all-style" data-url="widgets/clients/#grid-layout"><?php echo esc_html__("Design Styles","theplus"); ?></option>
															<option value="client-load-more" data-url="client-load-more-lazy-load"><?php echo esc_html__("Lazy Load/Load More","theplus"); ?></option>
															<option value="client-pagination" data-url="client-pagination"><?php echo esc_html__("Pagination","theplus"); ?></option>
														</optgroup>
														<optgroup label="<?php echo esc_html__("Image Gallery","theplus"); ?>">
															<option value="image-gallery-grid" data-url="plus-image-gallery/image-grid"><?php echo esc_html__("Grid","theplus"); ?></option>
															<option value="image-gallery-masonry" data-url="plus-image-gallery/image-masonry"><?php echo esc_html__("Masonry","theplus"); ?></option>
															<option value="image-gallery-metro" data-url="plus-image-gallery/image-metro"><?php echo esc_html__("Metro","theplus"); ?></option>
															<option value="image-gallery-carousel" data-url="plus-image-gallery/image-carousel"><?php echo esc_html__("Carousel","theplus"); ?></option>
															<option value="image-gallery-filter" data-url="plus-image-gallery/image-filter"><?php echo esc_html__("Filter","theplus"); ?></option>
															<option value="image-gallery-messy-columns" data-url="plus-image-gallery/image-messy-columns"><?php echo esc_html__("Messy Columns","theplus"); ?></option>
														</optgroup>

													</select>													
													<a class="listing-get-template-file" id="listing-download-template-file" /><?php echo esc_html__("Download File","theplus"); ?></a>
													<a href="#" class="plus-listing-demo-link" target="_blank"><?php echo esc_html__("Demo Link","theplus"); ?></a>
													<div class="loading-bar-plus"><i class="fa fa-spinner" aria-hidden="true"></i></div>
											</div>
									</div>
									<div class="pt-plus-section-content plus-pages" style="width:88%;">
											<div class="pt_plus_row">
													<h3><?php echo esc_html__("Plus Templates (.Json)","theplus"); ?></h3>
													<select name="plus-pages-templates" id="plus-pages-templates" class="form-control pt-plus-form-element">
														<option value=""><?php echo esc_html__("Coming Soon","theplus"); ?></option>														
													</select>													
													<a class="pages-get-template-file" id="pages-download-template-file" disabled /><?php echo esc_html__("Download File","theplus"); ?></a>
													<a href="#" class="plus-pages-demo-link" target="_blank"><?php echo esc_html__("Demo Link","theplus"); ?></a>
													<div class="loading-bar-plus"><i class="fa fa-spinner" aria-hidden="true"></i></div>
											</div>
									</div>
								</div>
								<div class="pt_col-md-6">										
										<div id="elementor-import-template-area" style="display:block;">											
											<form id="elementor-import-template-form" method="post" action="<?php echo admin_url( 'admin-ajax.php' ); ?>" enctype="multipart/form-data">
												<input type="hidden" name="action" value="elementor_library_direct_actions">
												<input type="hidden" name="library_action" value="direct_import_template">
												<input type="hidden" name="_nonce" value="<?php echo $ajax->create_nonce(); ?>">
												<h3><?php echo esc_html__("Import Designs (.Json)","theplus"); ?></h3>
												<fieldset id="elementor-import-template-form-inputs">
													<input type="file" name="file" accept=".json,application/json,.zip,application/octet-stream,application/zip,application/x-zip,application/x-zip-compressed" required>
													<input type="submit" class="button" value="<?php echo esc_attr__( 'Import Now', 'theplus' ); ?>">
												</fieldset>
											</form>
										</div>
									
								</div>
							</div>
						</div>
					</div>
				</div>				
				<?php } ?>
            	<?php  endforeach; ?>
		</div>
		<?php
    }
    
    /**
     * Defines the theme option metabox and field configuration
     * @since  1.0.0
     * @return array
     */
    public function option_fields($verify_api='')
    {
		
        // Only need to initiate the array once per page-load
        if (!empty($this->option_metabox)) {
            return $this->option_metabox;
        }
       
        $this->option_metabox[] = array(
            'id' => 'theplus_options',
            'title' => 'General Settings',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_options'
                )
            ),
            'show_names' => true,
            'fields' => array(
				array(
	                'name' => __('Widgets On/Off', 'theplus'),
	                'desc' => __('You can turn on/off widgets using this option. If you don\'t need all widgets, We suggest you to turn off them which help you to improve performance of website loading.', 'theplus'),
	                'id' => 'check_elements',
	                'type' => 'multicheck',
					'select_all_button' => true,
					'default' =>array('tp_accordion','tp_adv_text_block','tp_before_after','tp_blockquote','tp_blog_listout','tp_button','tp_cascading_image','tp_clients_listout','tp_contact_form_7','tp_countdown','tp_dynamic_device','tp_flip_box','tp_gallery_listout','tp_google_map','tp_heading_animation','tp_heading_title','tp_image_factory','tp_info_box','tp_mailchimp','tp_pricing_table','tp_row_background','tp_social_icon','tp_style_list','tp_switcher','tp_smooth_scroll','tp_tabs_tours','tp_team_member_listout','tp_testimonial_listout','tp_video_player'),
	                'options' => array(
	                    'tp_accordion' => __('Accordion', 'theplus'),
	                    'tp_adv_text_block' => __('Advanced Text Block', 'theplus'),
	                    'tp_before_after' => __('Before After', 'theplus'),
	                    'tp_blockquote' => __('Blockquote', 'theplus'),
	                    'tp_blog_listout' => __('Blog Listing', 'theplus'),
	                    'tp_button' => __('Button', 'theplus'),
	                    'tp_cascading_image' => __('Cascading Image', 'theplus'),
	                    'tp_clients_listout' => __('Clients Listing', 'theplus'),
	                    'tp_contact_form_7' => __('Contact Form 7', 'theplus'),
	                    'tp_countdown' => __('Count Down', 'theplus'),
	                    'tp_dynamic_device' => __('Dynamic Device', 'theplus'),
	                    'tp_flip_box' => __('Flip Box', 'theplus'),
	                    'tp_gallery_listout' => __('Gallery Listing', 'theplus'),
	                    'tp_google_map' => __('Google Map', 'theplus'),
	                    'tp_heading_animation' => __('Heading Animation', 'theplus'),
	                    'tp_heading_title' => __('Heading Title', 'theplus'),
	                    'tp_image_factory' => __('Creative Image', 'theplus'),
	                    'tp_info_box' => __('Info Box', 'theplus'),
	                    'tp_mailchimp' => __('Mailchimp', 'theplus'),
	                    'tp_pricing_table' => __('Pricing Table', 'theplus'),
	                    'tp_row_background' => __('Row Background', 'theplus'),
	                    'tp_social_icon' => __('Social Icon', 'theplus'),
	                    'tp_style_list' => __('Style List', 'theplus'),
	                    'tp_switcher' => __('Switcher', 'theplus'),
	                    'tp_smooth_scroll' => __('Smooth Scroll', 'theplus'),	                   
						'tp_tabs_tours' => __('Tabs/Tours', 'theplus'),
	                    'tp_team_member_listout' => __('Team Member Listing', 'theplus'),
	                    'tp_testimonial_listout' => __('Testimonial', 'theplus'),
	                    'tp_video_player' => __('Video Player', 'theplus'),
	                )	                
	            ),
				
				
            )
        );
        
        $this->option_metabox[] = array(
            'id' => 'post_type_options',
            'title' => 'Post Type Settings',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'post_type_options'
                )
            ),
            'show_names' => true,
            'fields' => array(				
				/* client option start */
				array(
					'name' => __('Clients Post Type Settings', 'theplus'),
					'desc' => '',
					'type' => 'title',
					'id' => 'client_post_title'
				),
				array(
						'name' => __('Select Post Type Type', 'theplus'),
						'desc' => '',
						'id' => 'client_post_type',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'disable',
						'options' => array(
							'disable' => __('Disable', 'theplus'),
							'plugin' => __('ThePlus Post Type', 'theplus'),
							'themes' => __('Prebuilt Theme Based', 'theplus'),
						)
				),
				array(
				'name' => __('Post Name : (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for clients custom post type name. Default: "theplus_clients"', 'theplus'),
				'default' => '',
				'id' => 'client_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'client_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Category Taxonomy Value : (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for Category Taxonomy Value. Default : "theplus_clients_cat" ', 'theplus'),
				'default' => '',
				'id' => 'client_category_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'client_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Prebuilt Post Name : (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current post type name which is prebuilt with your theme. E.g.: "theplus_clients" <a href="%s" class="thickbox" title="Get the Post Name of Custom Post type as per above Screenshot.">Check screenshot</a> for how to get that value from URL of your current post type.', 'theplus'), THEPLUS_URL.'assets/images/post-type-screenshot.png' ),
				'default' => '',
				'id' => 'client_theme_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'client_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				array(
				'name' => __('Prebuilt Category Taxonomy Value : (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current Category Taxonomy Value which is prebuilt with your theme.  E.g. : "theplus_clients_cat" <a href="%s" class="thickbox" title="Get the Category Taxonomy Value as per above screenshot.">Check screenshot</a> for how to get that value from URL of your current taxonomy.', 'theplus'), THEPLUS_URL.'assets/images/taxonomy-screenshot.png'),
				'default' => '',
				'id' => 'client_category_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'client_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				/* client option start */
				/* testimonial option start */
				array(
					'name' => __('Testimonial Post Type Settings', 'theplus'),
					'desc' => '',
					'type' => 'title',
					'id' => 'testimonial_post_title'
				),
				array(
						'name' => __('Select Post type Type', 'theplus'),
						'desc' => '',
						'id' => 'testimonial_post_type',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'disable',
						'options' => array(
							'disable' => __('Disable', 'theplus'),
							'plugin' => __('ThePlus Post Type', 'theplus'),
							'themes' => __('Prebuilt Theme Based', 'theplus'),
						)
				),
				array(
				'name' => __('Post Name : (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for testimonial custom post type name. Default: "theplus_testimonial"', 'theplus'),
				'default' => '',
				'id' => 'testimonial_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'testimonial_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Category Taxonomy Value : (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for Category Taxonomy Value. Default :"theplus_testimonial_cat"', 'theplus'),
				'default' => '',
				'id' => 'testimonial_category_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'testimonial_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Prebuilt Post Name : (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current post type name which is prebuilt with your theme. E.g.: "theplus_testimonial" <a href="%s" class="thickbox" title="Get the Post Name of Custom Post type as per above Screenshot.">Check screenshot</a> for how to get that value from URL of your current post type.', 'theplus'), THEPLUS_URL.'assets/images/post-type-screenshot.png' ),
				'default' => '',
				'id' => 'testimonial_theme_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'testimonial_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				array(
				'name' => __('Prebuilt Category Taxonomy Value : (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current Category Taxonomy Value which is prebuilt with your theme.  E.g. : "theplus_testimonial_cat" <a href="%s" class="thickbox" title="Get the Category Taxonomy Value as per above screenshot.">Check screenshot</a> for how to get that value from URL of your current taxonomy.', 'theplus'), THEPLUS_URL.'assets/images/taxonomy-screenshot.png' ),
				'default' => '',
				'id' => 'testimonial_category_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'testimonial_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				/* testimonial option start */
				/* Team Member option start */
				array(
					'name' => __('Team Member Post Type Settings','theplus'),
					'desc' => '',
					'type' => 'title',
					'id' => 'testimonial_post_title'
				),
				array(
						'name' => __('Select Team Member Post Type', 'theplus'),
						'desc' => '',
						'id' => 'team_member_post_type',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'disable',
						'options' => array(
							'disable' => __('Disable', 'theplus'),
							'plugin' => __('ThePlus Post Type', 'theplus'),
							'themes' => __('Prebuilt Theme Based', 'theplus'),
						)
				),
				array(
				'name' => __('Post Name : (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for team member custom post type name. Default: "theplus_team_member"', 'theplus'),
				'default' => '',
				'id' => 'team_member_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'team_member_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Category Taxonomy Value (Keep Blank if you want to keep default Name)', 'theplus'),
				'desc' => __('Enter value for Category Taxonomy Value. Default : "theplus_team_member_cat"', 'theplus'),
				'default' => '',
				'id' => 'team_member_category_plugin_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'team_member_post_type',
						'data-conditional-value' => 'plugin',
					),
				),
				array(
				'name' => __('Prebuilt Post Name : (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current post type name which is prebuilt with your theme. E.g.: "theplus_team_member" <a href="%s" class="thickbox" title="Get the Post Name of Custom Post type as per above Screenshot.">Check screenshot</a> for how to get that value from URL of your current post type.', 'theplus'), THEPLUS_URL.'assets/images/post-type-screenshot.png' ),
				'default' => '',
				'id' => 'team_member_theme_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'team_member_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				array(
				'name' => __('Prebuilt Category Taxonomy Value (You can find that from here)', 'theplus'),
				'desc' => sprintf( __('Enter the value of your current Category Taxonomy Value which is prebuilt with your theme.  E.g. : "theplus_team_member_cat" <a href="%s" class="thickbox" title="Get the Category Taxonomy Value as per above screenshot.">Check screenshot</a> for how to get that value from URL of your current taxonomy.', 'theplus'), THEPLUS_URL.'assets/images/taxonomy-screenshot.png' ),
				'default' => '',
				'id' => 'team_member_category_name',
				'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'team_member_post_type',
						'data-conditional-value' => 'themes',
					),
				),
				/* Team Member option start */
            )
        );
		$this->option_metabox[] = array(
            'id' => 'theplus_import_data',
            'title' => 'Plus Designs',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_import_data'
                )
            ),
            'show_names' => true,
        );
		$this->option_metabox[] = array(
            'id' => 'theplus_api_connection_data',
            'title' => 'API Connection',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_api_connection_data'
                )
            ),
            'show_names' => true,
            'fields' => array(
				array(
						'name' => __('Google Map API Key', 'pt_theplus'),
						'desc' => __('<b>NOTE :</b> Turn Off this key If you theme already have google key option. So, It will not generate error in console for multiple google map keys.', 'pt_theplus'),
						'id' => 'gmap_api_switch',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'enable',
						'options' => array(
							'enable' => __('Show', 'pt_theplus'),
							'disable' => __('Hide', 'pt_theplus'),
						),
				),
	            array(
	                'name' => __('Google Map API Key', 'pt_theplus'),
	                'desc' => __('This field is required if you want to use Advance Google Map element. You can obtain your own Google Maps Key here: (<a href="https://developers.google.com/maps/documentation/javascript/get-api-key">Click Here</a>)', 'pt_theplus'),
	                'default' => '',
	                'id' => 'theplus_google_map_api',
	                'type' => 'text',
					'attributes' => array(
						'data-conditional-id'    => 'gmap_api_switch',
						'data-conditional-value' => 'enable',
					),
	            ),
				array(
	                'name' => __('Mailchimp API Key', 'theplus'),
	                'desc' => __('Go to your Mailchimp > Account > Extras > API Keys then create a key and paste here', 'theplus'),
	                'default' => '',
	                'id' => 'theplus_mailchimp_api',
	                'type' => 'text',
	            ),
				array(
	                'name' => __('Mailchimp List ID', 'theplus'),
	                'desc' => __('Go to your Mailchimp > List > Settings > List name and default > Copy the list ID and paste here.', 'theplus'),
	                'default' => '',
	                'id' => 'theplus_mailchimp_id',
	                'type' => 'text',
	            ),
			),
        );
		$this->option_metabox[] = array(
            'id' => 'theplus_performance',
            'title' => 'Performance',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_performance'
                )
            ),
            'show_names' => true,
            'fields' => array(				
				array(
						'name' => __('Minify CSS', 'theplus'),
						'desc' => __('Enable Minified CSS to have faster performance of website. Disable it if it have any conflicts with your other plugins. If you are using cache plugins and do change status of this, do remove cache and test website. You need to do hard refresh.', 'theplus'),
						'id' => 'compress_minify_css',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'disable',
						'options' => array(
							'disable' => __('Disable', 'theplus'),
							'enable' => __('Enable', 'theplus'),
						)
				),
				array(
						'name' => __('Minified JS', 'theplus'),
						'desc' => __('Enable Minified JS to have faster performance of website. Disable it if it have any conflicts with your other plugins. If you are using cache plugins and do change status of this, do remove cache and test website. You need to do hard refresh.', 'theplus'),
						'id' => 'compress_minify_js',
						'type' => 'select',
						'show_option_none' => true,
						'default' => 'disable',
						'options' => array(
							'disable' => __('Disable', 'theplus'),
							'enable' => __('Enable', 'theplus'),
						)
				),
			),
        );
		$this->option_metabox[] = array(
            'id' => 'theplus_styling_data',
            'title' => 'Custom',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_styling_data'
                )
            ),
            'show_names' => true,
            'fields' => array(				
				array( 
					'name' => __( 'Custom CSS', 'theplus' ),
					'desc' => __( 'Add Your Custom CSS Styles', 'theplus' ),
					'id' => 'theplus_custom_css_editor',
					'type' => 'textarea_code',
				),
				array( 
					'name' => __( 'Custom JS', 'theplus' ),
					'desc' => __( 'Add Your Custom JS Scripts', 'theplus' ),
					'id' => 'theplus_custom_js_editor',
					'type' => 'textarea_code',
				),
			),
        );
		$this->option_metabox[] = array(
            'id' => 'theplus_about_us',
            'title' => 'About',
            'show_on' => array(
                'key' => 'options-page',
                'value' => array(
                    'theplus_about_us'
                )
            ),
            'show_names' => true,
        );
        return $this->option_metabox;
    }
   
    public function get_option_key($field_id)
    {
        $option_tabs = $this->option_fields();
        foreach ($option_tabs as $option_tab) { //search all tabs
            foreach ($option_tab['fields'] as $field) { //search all fields
                if ($field['id'] == $field_id) {
                    return $option_tab['id'];
                }
            }
        }
        return $this->key; //return default key if field id not found
    }
    /**
     * Public getter method for retrieving protected/private variables
     * @since  1.0.0
     * @param  string  $field Field to retrieve
     * @return mixed          Field value or exception is thrown
     */
    public function __get($field)
    {
        
        // Allowed fields to retrieve
        if (in_array($field, array('key','fields','title','options_page'), true)) {
            return $this->{$field};
        }
        if ('option_metabox' === $field) {
            return $this->option_fields();
        }
        
        throw new Exception('Invalid property: ' . $field);
    }
    
}


// Get it started
$Theplus_Elementor_Plugin_Options = new Theplus_Elementor_Plugin_Options();
$Theplus_Elementor_Plugin_Options->hooks();

/**
 * Wrapper function around cmb_get_option
 * @since  1.0.0
 * @param  string  $key Options array key
 * @return mixed        Option value
 */
function theplus_ele_get_option($key = '')
{
    global $Theplus_Elementor_Plugin_Options;
    return cmb_get_option($Theplus_Elementor_Plugin_Options->key, $key);
}